# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2026-01-04

### Changed

- Migrate raindropio-mcp to mcp-common v0.4.4
- Update config, core, deps, tests

## [0.1.3] - 2025-12-20

### Changed

- Update config, core, deps, docs, tests

### Fixed

- test: Update 181 files
